@@ -12,7 +12,7 @@ use Package::Util::Lite qw(package_exists);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-04-17'; # DATE
 our $DIST = 'Module-Patch'; # DIST
-our $VERSION = '0.277'; # VERSION
+our $VERSION = '0.278'; # VERSION
 
 our @EXPORT_OK = qw(patch_package);
 
@@ -294,7 +294,7 @@ Module::Patch - Patch package with a set of patches
 
 =head1 VERSION
 
-This document describes version 0.277 of Module::Patch (from Perl distribution Module-Patch), released on 2024-04-17.
+This document describes version 0.278 of Module::Patch (from Perl distribution Module-Patch), released on 2024-04-17.
 
 =head1 SYNOPSIS
 
@@ -393,7 +393,7 @@ In your patch module F<lib/HTTP/Tiny/Patch/Retry.pm>:
                      $res;
                  };
              },
-         ], # patched
+         ], # patches
 
          # other Module::Patch import options can be specified here
          # -load_target => 1,
